@@ -21,22 +21,12 @@
 #include <QElapsedTimer>
 #include <QPair>
 #include <QList>
-#include <QXmlSimpleReader>
+#include <QXmlStreamReader>
 
-#ifdef Q_OS_WIN
-#define U QLatin1String
-#else
-#define U QStringLiteral
-#endif
-
-static const QString noyes[] = {U("no"), U("yes")};
-static const QString bintargettarget[] = {U("bin-target"), U("target")};
-static const QString binsourcesource[] = {U("bin-source"), U("source")};
-static const QString NOTE = U("note");
-XliffStorage::XliffStorage()
-    : CatalogStorage()
-{
-}
+static const QString noyes[] = {QStringLiteral("no"), QStringLiteral("yes")};
+static const QString bintargettarget[] = {QStringLiteral("bin-target"), QStringLiteral("target")};
+static const QString binsourcesource[] = {QStringLiteral("bin-source"), QStringLiteral("source")};
+static const QString NOTE = QStringLiteral("note");
 
 int XliffStorage::capabilities() const
 {
@@ -47,17 +37,15 @@ int XliffStorage::capabilities() const
 
 int XliffStorage::load(QIODevice* device)
 {
-    QElapsedTimer chrono; chrono.start();
+    QElapsedTimer chrono;
+    chrono.start();
 
-
-    QXmlSimpleReader reader;
-    reader.setFeature(QStringLiteral("http://qt-project.org/xml/features/report-whitespace-only-CharData"), true);
-    reader.setFeature(QStringLiteral("http://xml.org/sax/features/namespaces"), false);
-    QXmlInputSource source(device);
+    QXmlStreamReader reader(device);
+    reader.setNamespaceProcessing(false);
 
     QString errorMsg;
-    int errorLine;//+errorColumn;
-    bool success = m_doc.setContent(&source, &reader, &errorMsg, &errorLine/*,errorColumn*/);
+    int errorLine{};//+errorColumn;
+    bool success = m_doc.setContent(&reader, false, &errorMsg, &errorLine/*,errorColumn*/);
 
     QString FILE = QStringLiteral("file");
     if (!success || m_doc.elementsByTagName(FILE).isEmpty()) {
@@ -76,10 +64,10 @@ int XliffStorage::load(QIODevice* device)
     //we create any form-entries additionally needed
 
     entries = m_doc.elementsByTagName(QStringLiteral("trans-unit"));
-    int size = entries.size();
+    int nodeListSize = entries.size();
     m_map.clear();
-    m_map.reserve(size);
-    for (int i = 0; i < size; ++i) {
+    m_map.reserve(nodeListSize);
+    for (int i = 0; i < nodeListSize; ++i) {
         QDomElement parentElement = entries.at(i).parentNode().toElement();
         //if (Q_UNLIKELY( e.isNull() ))//sanity
         //      continue;
@@ -89,7 +77,7 @@ int XliffStorage::load(QIODevice* device)
         if (parentElement.tagName() == QLatin1String("group") && parentElement.attribute(QStringLiteral("restype")) == QLatin1String("x-gettext-plurals")) {
             m_plurals.insert(i);
             int localPluralNum = m_numberOfPluralForms;
-            while (--localPluralNum > 0 && (++i) < size) {
+            while (--localPluralNum > 0 && (++i) < nodeListSize) {
                 QDomElement p = entries.at(i).parentNode().toElement();
                 if (p.tagName() == QLatin1String("group") && p.attribute(QStringLiteral("restype")) == QLatin1String("x-gettext-plurals"))
                     continue;
@@ -100,9 +88,9 @@ int XliffStorage::load(QIODevice* device)
     }
 
     binEntries = m_doc.elementsByTagName(QStringLiteral("bin-unit"));
-    size = binEntries.size();
+    nodeListSize = binEntries.size();
     int offset = m_map.size();
-    for (int i = 0; i < size; ++i)
+    for (int i = 0; i < nodeListSize; ++i)
         m_unitsById[binEntries.at(i).toElement().attribute(QStringLiteral("id"))] = offset + i;
 
 //    entries=m_doc.elementsByTagName("body");
@@ -181,15 +169,13 @@ struct ContentEditingData {
 
     QList<InlineTag> tags;
     QString stringToInsert;
-    int pos;
-    int lengthOfStringToRemove;
+    int pos{-1};
+    int lengthOfStringToRemove{-1};
     ActionType actionType;
 
     ///Get
-    ContentEditingData(ActionType type = Get)
-        : pos(-1)
-        , lengthOfStringToRemove(-1)
-        , actionType(type)
+    explicit ContentEditingData(ActionType type = Get)
+        : actionType(type)
     {}
 
     ///DeleteText
@@ -217,9 +203,8 @@ struct ContentEditingData {
     }
 
     ///DeleteTag
-    ContentEditingData(int p)
+    explicit ContentEditingData(int p)
         : pos(p)
-        , lengthOfStringToRemove(-1)
         , actionType(DeleteTag)
     {}
 
@@ -245,7 +230,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
     QString result;
 
     if (elem.isNull()
-        || (!result.isEmpty() && data && data->actionType == ContentEditingData::CheckLength))
+        || (data && data->actionType == ContentEditingData::CheckLength))
         return QString();
 
     bool seenCharacterDataAfterElement = false;
@@ -278,7 +263,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
                         //qCWarning(LOKALIZE_LOG)<<"simple delete"<<localStartPos<<data->lengthOfStringToRemove;
                         c.deleteData(localStartPos, data->lengthOfStringToRemove);
                         data->actionType = ContentEditingData::CheckLength;
-                        return QString('a');//so it exits 100%
+                        return QStringLiteral("a");//so it exits 100%
                     }
                 }
                 //END DELETE TEXT
@@ -286,7 +271,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
                 else if (data->actionType == ContentEditingData::InsertText) {
                     c.insertData(localStartPos, data->stringToInsert);
                     data->actionType = ContentEditingData::CheckLength;
-                    return QString('a');//so it exits 100%
+                    return QStringLiteral("a");//so it exits 100%
                 }
                 //BEGIN INSERT TAG
                 else if (data->actionType == ContentEditingData::InsertTag) {
@@ -295,7 +280,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
                     qCDebug(LOKALIZE_LOG) << "inserting tag" << tag.name() << tag.id << tag.start << tag.end << mid << data->pos << startingPos;
                     if (mid.size())
                         c.deleteData(localStartPos, mid.size());
-                    QDomElement newNode = elem.insertAfter(elem.ownerDocument().createElement(tag.getElementName()), n).toElement();
+                    QDomElement newNode = elem.insertAfter(elem.ownerDocument().createElement(QLatin1String(tag.getElementName())), n).toElement();
                     newNode.setAttribute(QStringLiteral("id"), tag.id);
                     if (!tag.xid.isEmpty())
                         newNode.setAttribute(QStringLiteral("xid"), tag.xid);
@@ -374,7 +359,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
             if (data && data->actionType == ContentEditingData::DeleteTag
                 && data->pos == startingPos) {
                 //qCWarning(LOKALIZE_LOG)<<"start deleting tag";
-                data->tags.append(InlineTag(startingPos, -1, InlineTag::getElementType(el.tagName().toUtf8()), el.attribute("id"), el.attribute("xid")));
+                data->tags.append(InlineTag(startingPos, -1, InlineTag::getElementType(el.tagName().toUtf8()), el.attribute(QStringLiteral("id")), el.attribute(QStringLiteral("xid"))));
                 if (data->tags.first().isPaired()) {
                     //get end position
                     ContentEditingData subData(ContentEditingData::Get);
@@ -455,7 +440,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
 
 CatalogString XliffStorage::catalogString(QDomElement unit,  DocPosition::Part part) const
 {
-    static const QString names[] = {U("source"), U("target"), U("seg-source")};
+    static const QString names[] = {QStringLiteral("source"), QStringLiteral("target"), QStringLiteral("seg-source")};
     CatalogString catalogString;
     ContentEditingData data(ContentEditingData::Get);
     int nameIndex = part == DocPosition::Target;
@@ -495,7 +480,7 @@ QString XliffStorage::sourceWithPlurals(const DocPosition& pos, bool truncateFir
 {
     QString str = source(pos);
     if (truncateFirstLine) {
-        int truncatePos = str.indexOf("\n");
+        int truncatePos = str.indexOf(QLatin1Char('\n'));
         if (truncatePos != -1)
             str.truncate(truncatePos);
     }
@@ -505,7 +490,7 @@ QString XliffStorage::targetWithPlurals(const DocPosition& pos, bool truncateFir
 {
     QString str = target(pos);
     if (truncateFirstLine) {
-        int truncatePos = str.indexOf("\n");
+        int truncatePos = str.indexOf(QLatin1Char('\n'));
         if (truncatePos != -1)
             str.truncate(truncatePos);
     }
@@ -602,7 +587,7 @@ QVector<AltTrans> XliffStorage::altTrans(const DocPosition& pos) const
         };
         QString typeStr = elem.attribute(QStringLiteral("alttranstype"));
         int i = -1;
-        while (++i < int(sizeof(types) / sizeof(char*)) && types[i] != typeStr)
+        while (++i < int(sizeof(types) / sizeof(char*)) && QLatin1String(types[i]) != typeStr)
             ;
         aTrans.type = AltTrans::Type(i);
 
@@ -718,19 +703,19 @@ QStringList XliffStorage::sourceFiles(const DocPosition& pos) const
     QDomElement elem = unitForPos(pos.entry).firstChildElement(QStringLiteral("context-group"));
     while (!elem.isNull()) {
         if (elem.attribute(QStringLiteral("purpose")).contains(QLatin1String("location"))) {
-            QDomElement context = elem.firstChildElement(QStringLiteral("context"));
-            while (!context.isNull()) {
+            QDomElement contextElem = elem.firstChildElement(QStringLiteral("context"));
+            while (!contextElem.isNull()) {
                 QString sourcefile;
                 QString linenumber;
-                const QString contextType = context.attribute(QStringLiteral("context-type"));
+                const QString contextType = contextElem.attribute(QStringLiteral("context-type"));
                 if (contextType == QLatin1String("sourcefile"))
-                    sourcefile = context.text();
+                    sourcefile = contextElem.text();
                 else if (contextType == QLatin1String("linenumber"))
-                    linenumber = context.text();
+                    linenumber = contextElem.text();
                 if (!(sourcefile.isEmpty() && linenumber.isEmpty()))
-                    result.append(sourcefile + ':' + linenumber);
+                    result.append(sourcefile + QLatin1Char(':') + linenumber);
 
-                context = context.nextSiblingElement(QStringLiteral("context"));
+                contextElem = contextElem.nextSiblingElement(QStringLiteral("context"));
             }
         }
 
@@ -816,10 +801,10 @@ Note XliffStorage::setNote(DocPosition pos, const Note& note)
 QStringList XliffStorage::noteAuthors() const
 {
     QSet<QString> result;
-    QDomNodeList notes = m_doc.elementsByTagName(NOTE);
-    int i = notes.size();
+    QDomNodeList notesNodes = m_doc.elementsByTagName(NOTE);
+    int i = notesNodes.size();
     while (--i >= 0) {
-        QString from = notes.at(i).toElement().attribute(QStringLiteral("from"));
+        QString from = notesNodes.at(i).toElement().attribute(QStringLiteral("from"));
         if (!from.isEmpty())
             result.insert(from);
     }
@@ -873,20 +858,20 @@ QString XliffStorage::setPhase(const DocPosition& pos, const QString& phase)
     QString PHASENAME = QStringLiteral("phase-name");
     targetInsert(pos, QString()); //adds <taget> if needed
 
-    QDomElement target = targetForPos(pos.entry);
-    QString result = target.attribute(PHASENAME);
+    QDomElement targetElem = targetForPos(pos.entry);
+    QString result = targetElem.attribute(PHASENAME);
     if (phase.isEmpty())
-        target.removeAttribute(PHASENAME);
+        targetElem.removeAttribute(PHASENAME);
     else if (phase != result)
-        target.setAttribute(PHASENAME, phase);
+        targetElem.setAttribute(PHASENAME, phase);
 
     return result;
 }
 
 QString XliffStorage::phase(const DocPosition& pos) const
 {
-    QDomElement target = targetForPos(pos.entry);
-    return target.attribute(QStringLiteral("phase-name"));
+    QDomElement targetElem = targetForPos(pos.entry);
+    return targetElem.attribute(QStringLiteral("phase-name"));
 }
 
 QStringList XliffStorage::context(const DocPosition& pos) const
@@ -924,9 +909,9 @@ void XliffStorage::setApproved(const DocPosition& pos, bool approved)
 */
 
 static const QString xliff_states[] = {
-    U("new"), U("needs-translation"), U("needs-l10n"), U("needs-adaptation"), U("translated"),
-    U("needs-review-translation"), U("needs-review-l10n"), U("needs-review-adaptation"),
-    U("final"), U("signed-off")
+    QStringLiteral("new"), QStringLiteral("needs-translation"), QStringLiteral("needs-l10n"), QStringLiteral("needs-adaptation"), QStringLiteral("translated"),
+    QStringLiteral("needs-review-translation"), QStringLiteral("needs-review-l10n"), QStringLiteral("needs-review-adaptation"),
+    QStringLiteral("final"), QStringLiteral("signed-off")
 };
 
 
@@ -941,9 +926,9 @@ TargetState stringToState(const QString& state)
 TargetState XliffStorage::setState(const DocPosition& pos, TargetState state)
 {
     targetInsert(pos, QString()); //adds <taget> if needed
-    QDomElement target = targetForPos(pos.entry);
-    TargetState prev = stringToState(target.attribute(QStringLiteral("state")));
-    target.setAttribute(QStringLiteral("state"), xliff_states[state]);
+    QDomElement targetElem = targetForPos(pos.entry);
+    TargetState prev = stringToState(targetElem.attribute(QStringLiteral("state")));
+    targetElem.setAttribute(QStringLiteral("state"), xliff_states[state]);
 
     unitForPos(pos.entry).setAttribute(QStringLiteral("approved"), noyes[state == SignedOff]);
     return prev;
@@ -951,10 +936,10 @@ TargetState XliffStorage::setState(const DocPosition& pos, TargetState state)
 
 TargetState XliffStorage::state(const DocPosition& pos) const
 {
-    QDomElement target = targetForPos(pos.entry);
-    if (!target.hasAttribute(QStringLiteral("state")) && unitForPos(pos.entry).attribute(QStringLiteral("approved")) == QLatin1String("yes"))
+    QDomElement targetElem = targetForPos(pos.entry);
+    if (!targetElem.hasAttribute(QStringLiteral("state")) && unitForPos(pos.entry).attribute(QStringLiteral("approved")) == QLatin1String("yes"))
         return SignedOff;
-    return stringToState(target.attribute(QStringLiteral("state")));
+    return stringToState(targetElem.attribute(QStringLiteral("state")));
 }
 
 bool XliffStorage::isEmpty(const DocPosition& pos) const
