@@ -22,9 +22,7 @@
 
 //these are run in separate thread
 UpdateStatsJob::UpdateStatsJob(const QList<KFileItem> &files, QObject*)
-    : QRunnable()
-    , m_files(files)
-    , m_status(0)
+    : m_files(files)
 {
     setAutoDelete(false);
 }
@@ -138,3 +136,5 @@ void UpdateStatsJob::setStatus(int status)
 {
     m_status = status;
 }
+
+#include "moc_updatestatsjob.cpp"
